﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;
using MindFusion.Charting.Wpf;

namespace LineChartPerformance
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private DispatcherTimer timer = new DispatcherTimer();
        private Random random = new Random();
        private int maxX = 100;

        public MainWindow()
        {
            InitializeComponent();


            Initialize();
           
            timer.Interval = TimeSpan.FromMilliseconds(100);
            timer.Tick += new EventHandler(OnTimerTick);
        }

        private void OnTimerTick(object sender, EventArgs e)
        {
            lineChart.BeginInit();

            foreach (LineSeries series in lineChart.Series)
            {
                for (int i = 10 - 1; i >= 0; i--)
                {
                    series.XData.Remove(series.XData[i]);
                    series.YData.Remove(series.YData[i]);
                }
            }

            int counter = 0;
            foreach (LineSeries series in lineChart.Series)
            {
                for (int i = 0; i < 10; i++)
                {
                    series.XData.Add(i + maxX);
                    series.YData.Add(10 + counter * 10 + random.Next(-5, 5));
                }

                counter++;
            }

            maxX += 10;
            lineChart.XAxisSettings.MinValue += 10;


            lineChart.EndInit();
        }

        private Brush RandomStroke
        {
            get
            {
                byte r = (byte)random.Next(0, 255);
                byte g = (byte)random.Next(0, 255);
                byte b = (byte)random.Next(0, 255);
                return new SolidColorBrush(Color.FromArgb(255, r, g, b));
            }
        }

        private void Initialize()
        {
            lineChart.BeginInit();

            lineChart.XAxisSettings.MinValue = 0;
            lineChart.XAxisSettings.Interval = 10;
            lineChart.XAxisSettings.LabelType = LabelType.AutoScale;

            
            
            for (int i = 0; i < 8; i++)
            {
                LineSeries series = new LineSeries();
                series.StrokeThickness = 1;
                series.Strokes.Add(RandomStroke);
                series.Fills = series.Strokes;
                series.Title = "Series" + i;
                series.XData = new DoubleCollection();
                series.YData = new DoubleCollection();

                for (int j = 0; j < 100; j++)
                {
                    series.XData.Add(j);
                    series.YData.Add(10 + 10 * i + random.Next(-5, 5));
                }

                lineChart.Series.Add(series);
            }

            ChartLegend legend = new ChartLegend();
            legend.Series = lineChart.Series;
            lineChart.Legends.Add(legend);

            lineChart.EndInit();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            timer.IsEnabled = !timer.IsEnabled;
        }
    }
}
